@@ -11,7 +11,7 @@ from subprocess import Popen, PIPE
 from dataclasses import dataclass
 
 
-__version__ = "0.2.19"
+__version__ = "0.3.1"
 
 CFG_DIR = os.path.expanduser("~/.venvipy")
 DB_FILE = os.path.expanduser("~/.venvipy/py-installs")
@@ -102,21 +102,19 @@ def get_python_installs(relaunching=False):
                 python_path = shutil.which(f"python{version}")
                 if python_path is not None:
                     python_version = get_python_version(python_path)
-
                     py_info = PythonInfo(python_version, python_path)
                     py_info_list.append(py_info)
-
                     writer.writerow({
                         "PYTHON_VERSION": py_info.py_version,
                         "PYTHON_PATH": py_info.py_path
                     })
 
-                    # if we're running in a virtual environment we might
-                    # need to add the system's Python manually
-                    if "VIRTUAL_ENV" in os.environ:
-                        system_python = os.path.realpath(sys.executable)
-                        if py_info.py_path != system_python:
-                            add_python(system_python)
+            cf.close()
+
+            # add the system's Python manually if running in a virtual env
+            if "VIRTUAL_ENV" in os.environ:
+                system_python = os.path.realpath(sys.executable)
+                add_python(system_python)
 
         return py_info_list[::-1]
     return False
@@ -140,16 +138,17 @@ def add_python(py_path):
             "PYTHON_VERSION": get_python_version(py_path),
             "PYTHON_PATH": py_path
         })
-    # if in a virtual env we will remove our Python
-    # from the database (we don't need it anyway)
+        cf.close()
+
+    # remove the interpreter if running in a virtual env
     if "VIRTUAL_ENV" in os.environ:
         remove_env()
 
 
 def remove_env():
     """
-    Remove our env if we're running in a virtual
-    environment, then save a new copy of `py-installs`.
+    Remove our interpreter if we're running in a virtual
+    environment.
     """
     with open(DB_FILE, "r") as f:
         lines = f.readlines()
